<TS language="es" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Acerca de Gridcoin</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Crear una nueva dirección</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copiar la dirección seleccionada al portapapeles del sistema</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Enseñar &amp;QR Code</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Firmar un mensaje para demostrar que es dueño de su dirección de Gridcoin</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Firmar &amp;Mensaje</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Verifique el mensaje para asegurarse que fue firmado por una dirección específica de Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifique Mensaje</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Eliminar la dirección seleccionada de la lista</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Directorio</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Estas son las direcciones de Gridcoin para recibir pagos. Es posible que desee dar una diferente a cada remitente para que pueda realizar un seguimiento de quien te está pagando.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copiar &amp;Etiqueta</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Exportar Data de Libro de Direcciones</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Error exportando</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>No se pudo escribir en el archivo %1.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Diálogo de contraseña</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Introducir contraseña</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nueva contraseña</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repita la nueva contraseña</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>Sirve para desactivar SendMoney cuando la cuenta del Sistema Operativo está comprometida. No ofrece seguridad real.</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Para "Staking" solamente</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Introduzca la nueva contraseña del monedero. &lt;br/&gt;Por favor utilice una contraseña de &lt;b&gt;diez o más carácteres aleatorios&lt;/b&gt;, o &lt;b&gt;ocho o más palabras&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Cifrar monedero</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Esta operación necesita su contraseña de monedero para desbloquear el monedero.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloquear monedero</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Cambiar contraseña</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Introduzca la contraseña anterior del monedero y la nueva. </translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirmar cifrado del monedero</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Advertencia: Si encripta su cartera y pierde su frase de contraseña, puede &lt;b&gt;PERDER TODAS SUS MONEDAS&lt;/ b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>¿Seguro que desea cifrar su monedero?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Monedero cifrado</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>Gridcoin cerrará para terminar el proceso de encriptación. Recuerde que la encriptación de su monedero no puede proteger completamente que sus monedas sean robadas por malware infectando su computadora.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>IMPORTANTE: Cualquier copia de seguridad anterior que haya hecho en su archivo de monedero debería ser reemplazada con el archivo de monedero cifrado generado recientemente. Por razones de seguridad, las copias de seguridad anteriores del archivo de monedero descifrado serán inútiles en cuanto empiece a utilizar el nuevo monedero cifrado.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Fracasó el cifrado del monedero</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Falló el cifrado del monedero debido a un error interno. Su monedero no fue cifrado.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>La contraseña introducida no coincide.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Fracasó el desbloqueo del monedero</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>La contraseña introducida para el cifrado del monedero es incorrecta.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>La contraseña del monedero se ha cambiado con éxito.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Alerta: ¡La clave de bloqueo Caps está activa!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
        <translation>Se ha producido un error fatal. Gridcoin ya no puede continuar de forma segura y cerrará.</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Monedero</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Vista general</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Mostrar vista general del monedero</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Enviar</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Enviar monedas a una dirección de Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Recibir</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Mostrar la lista de direcciones para recibir pagos</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Examinar el historial de transacciones</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Editar la lista de direcciones y etiquetas almacenadas</translation>
    </message>
    <message>
        <source>&amp;Voting</source>
        <translation>&amp;Votación</translation>
    </message>
    <message>
        <source>Voting</source>
        <translation>Votación</translation>
    </message>
    <message>
        <source>&amp;Block Explorer</source>
        <translation>&amp;Bloquear Explorador
</translation>
    </message>
    <message>
        <source>Block Explorer</source>
        <translation>Explorador de bloques</translation>
    </message>
    <message>
        <source>&amp;Exchange</source>
        <translation>&amp;Intercambiar</translation>
    </message>
    <message>
        <source>Web Site</source>
        <translation>Sitio Web</translation>
    </message>
    <message>
        <source>&amp;Web Site</source>
        <translation>&amp;Sitio Web</translation>
    </message>
    <message>
        <source>&amp;GRC Chat Room</source>
        <translation>&amp;Sala de Chat de GRC</translation>
    </message>
    <message>
        <source>GRC Chatroom</source>
        <translation>Sala de Chat de GRC</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>S&amp;alir</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Salir de la aplicación</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>&amp;Acerca de Gridcoin</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Mostrar información sobre Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Diagnostics</source>
        <translation>&amp;Diagnóstico</translation>
    </message>
    <message>
        <source>Diagnostics</source>
        <translation>Diagnóstico</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opciones...</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>Modificar las opciones de configuración para Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Mostrar / Ocultar</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Cifrar monedero…</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Cambiar la contraseña…</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Cambiar la contraseña utilizada para el cifrado del monedero</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>&amp;Desbloquear Monedero...</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloquear el monedero</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Bloquear monedero</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Bloquear monedero</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Firmar &amp;mensaje...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verificar mensaje...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Exportar...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exportar los datos en la ficha actual a un archivo</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Ventana de depuración</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Abrir la consola de depuración y diagnóstico</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Cliente Gridcoin</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Actualizado</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Actualizando...</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>Último bloque recibido se generó en %1.</translation>
    </message>
    <message>
        <source>This transaction is over the size limit.  You can still send it for a fee of %1, which goes to the nodes that process your transaction and helps to support the network.  Do you want to pay the fee?</source>
        <translation>Esta transacción se encuentra sobre el límite de tamaño. Usted todavía puede enviarlo a un costo de %1, lo que va a los nodos que procesan sus transacciones y ayuda a apoyar la red. ¿Quieres pagar la cuota?</translation>
    </message>
    <message>
        <source>Confirm transaction fee</source>
        <translation>Confirme tarifa de transacción</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transacción enviada</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transacción entrante</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>Manejar URI</translation>
    </message>
    <message>
        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
        <translation>URI no se puede analizar! Esto puede ser causado por una dirección de Gridcoin no válida o parámetros de URI malformados.</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>El monedero está &lt;b&gt;cifrado&lt;/b&gt; y actualmente &lt;b&gt;bloqueado&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Copia de Seguridad de Monedero</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Data de Monedero (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Copia de Seguridad a fracasado</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to the new location.</source>
        <translation>Hubo un error al tratar de salvar los datos de su monedero a la nueva ubicación.</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Alerta de red</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Cantidad:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Cuantía:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Tasa:</translation>
    </message>
    <message>
        <source>Coin Control</source>
        <translation>Control de Moneda</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Envío pequeño:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Después de aplicar la comisión:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Cambio:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Confirmaciones</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copiar ubicación</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copiar etiqueta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiar cantidad</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copiar ID de transacción</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copiar cantidad</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copiar comisión</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copiar después de couta</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copiar bytes</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copiar envío pequeño</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copiar cambio</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>sí</translation>
    </message>
    <message>
        <source>This label turns red, if the transaction size is bigger than 10000 bytes.

 This means a fee of at least %1 per kb is required.

 Can vary +/- 1 Byte per input.</source>
        <translation>Esta etiqueta se convierte en rojo, si el tamaño de la transacción es mayor que 10000 bytes.

Esto significa que se requiere una cuota de al menos el %1 por kb.

Puede variar + / - 1 Byte por entrada.</translation>
    </message>
    <message>
        <source>This label turns red, if any recipient receives an amount smaller than %1.

 This means a fee of at least %2 is required. 

 Amounts below 0.546 times the minimum relay fee are shown as DUST.</source>
        <translation>Esta etiqueta se convierte en rojo, si cualquier recipiente recibe una cantidad menor que %1.

Esto significa que se requiere una cuota de al menos %2.

Las cantidades inferiores a 0.546 veces la cuota mínima del relé se muestran en forma de DUST.</translation>
    </message>
    <message>
        <source>This label turns red, if the change is smaller than %1.

 This means a fee of at least %2 is required.</source>
        <translation>Esta etiqueta se convierte en rojo, si el cambio es menor que %1.

Esto significa que se requiere una cuota de al menos %2.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>cambia desde %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(cambio)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Editar Dirección</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiqueta</translation>
    </message>
    <message>
        <source>The label associated with this address book entry</source>
        <translation>La etiqueta asociada con esta entrada de la libreta de direcciones</translation>
    </message>
    <message>
        <source>The address associated with this address book entry. This can only be modified for sending addresses.</source>
        <translation>La dirección asociada con esta entrada de la libreta de direcciones. Esto sólo puede ser modificada para direcciones de envío.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Dirección</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nueva dirección de recivimiento</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nueva dirección de envío</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Editar dirección de recivimiento</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Editar dirección de envío</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Gridcoin address.</source>
        <translation>La dirección introducida "%1" no es una dirección válida de Gridcoin.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>La dirección introducida "%1" está ya en la agenda.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Podría no desbloquear el monedero.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Falló la generación de la nueva clave.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Uso:</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>opciones de líneas de comandos</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Principal</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Red</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapear el puerto mediante &amp;UPnP</translation>
    </message>
    <message>
        <source>Automatically start Gridcoin after logging in to the system.</source>
        <translation>Iniciar Gridcoin automáticamente después de entrar en el sistema.</translation>
    </message>
    <message>
        <source>&amp;Start Gridcoin on system login</source>
        <translation>&amp;Iniciar Gridcoin al inicio del sistema</translation>
    </message>
    <message>
        <source>Automatically open the Gridcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Abrir automáticamente el puerto de cliente Gridcoin en el router. Esto sólo funciona cuando el router es compatible con UPnP y está habilitado.</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. 127.0.0.1)</source>
        <translation>Dirección IP del proxy (e.g. 127.0.0.1)</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Puerto:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Puerto del servidor proxy (ej. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minimizar en lugar de salir de la aplicación al cerrar la ventana. Cuando esta opción está activa, la aplicación solo se puede cerrar seleccionando Salir desde el menú.</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting Gridcoin.</source>
        <translation>El idioma del interfaz de usuario se puede configurar aquí. Esta configuración se aplicará después de reiniciar Gridcoin.</translation>
    </message>
    <message>
        <source>Whether to show Gridcoin addresses in the transaction list or not.</source>
        <translation>Tanto para mostrar direcciones de Gridcoin en la lista de transacciones o no.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Mostrar las direcciones en la lista de transacciones</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ventana</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Aplicar</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Minimizar la ventana a la bandeja de iconos del sistema.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimizar a la bandeja en vez de a la barra de tareas</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimizar al cerrar</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Interfaz</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>I&amp;dioma de la interfaz de usuario</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unidad en la cual mostrar las cantidades:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Elegir la subdivisión predeterminada para mostrar cantidades en la interfaz y cuando se envían bitcoins.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>default</source>
        <translation>predeterminado</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <source>This setting will take effect after restarting Gridcoin.</source>
        <translation>Esta configuración se aplicará después de reiniciar Gridcoin.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>La dirección proxy indicada es inválida.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Disponible:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Su saldo disponible actual</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>No madurado:</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Gridcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>La información mostrada puede estar fuera de fecha. Su monedera se sincroniza automáticamente con la red Gridcoin después de que se establece una conexión, pero este proceso no se ha completado todavía.</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the current balance</source>
        <translation>Total de transacciones que aún no se han confirmado, y aún no cuentan para el balance actual</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Su saldo actual total</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>QR Code Dialog</source>
        <translation>Código Diálogo QR</translation>
    </message>
    <message>
        <source>Request Payment</source>
        <translation>Solicitar Pago</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Etiqueta:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mensaje:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Cantidad:</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Guardar como....</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Error codificando URI en código QR??.</translation>
    </message>
    <message>
        <source>The entered amount is invalid, please check.</source>
        <translation>La cantidad introducida es inválida, compruebe por favor.</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>URI resultante demasiado largo, trate de reducir el texto de etiqueta / mensaje.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Guardar código QR</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Versión del cliente</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Información</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Hora de inicio</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Número de conexiones</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Cadena de bloques</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Número actual de bloques</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Hora del último bloque</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Vaciar</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Consola</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Tráfico de Red</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Total:</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Entrante:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Saliente:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Archivo de registro de depuración</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Borrar consola</translation>
    </message>
    <message>
        <source>Gridcoin - Debug Console</source>
        <translation>Gridcoin - Consola de depuración</translation>
    </message>
    <message>
        <source>Boost version</source>
        <translation>Versión de Boost</translation>
    </message>
    <message>
        <source>Gridcoin Core:</source>
        <translation>Gridcoin Núcleo:</translation>
    </message>
    <message>
        <source>Network:</source>
        <translation>Red:</translation>
    </message>
    <message>
        <source>On testnet</source>
        <translation>En testnet</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Bloques totales estimados</translation>
    </message>
    <message>
        <source>Open the Gridcoin debug log file from the current data directory. This can take a few seconds for large log files.</source>
        <translation>Abre el archivo de registro de Gridcoin del directorio de datos actual. Esto puede tardar algunos segundos para archivos grandes.</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Opciones de línea de comandos</translation>
    </message>
    <message>
        <source>Show the Gridcoin help message to get a list with possible Gridcoin command-line options.</source>
        <translation>Mostrar el mensaje de ayuda de Gridcoin-Qt para obtener una lista con las posibles opciones de línea de comandos para Gridcoin.</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>&amp;Mostrar</translation>
    </message>
    <message>
        <source>OpenSSL version</source>
        <translation>Versión de OpenSSL</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Nombre del cliente</translation>
    </message>
    <message>
        <source>Welcome to the Gridcoin RPC console! </source>
        <translation>¡Bienvenido a la consola RPC de Gridcoin!</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Use las flechas arriba y abajo para navegar por el historial y &lt;b&gt;Control+L&lt;/b&gt; para vaciar la pantalla.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Escriba &lt;b&gt;help&lt;/b&gt; para ver un resumen de los comandos disponibles.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Enviar bitcoins</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Entradas...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>Seleccionado automáticamente</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fondos insuficientes!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Cantidad:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Cuantía:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Tasa:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Envío pequeño:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Después de tasas:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Cambio</translation>
    </message>
    <message>
        <source>custom change address</source>
        <translation>dirección de cambio personalizada</translation>
    </message>
    <message>
        <source>Remove all transaction fields</source>
        <translation>Elimina todos los campos de transacciones</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Enviar a múltiples destinatarios de una vez</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Añadir &amp;destinatario</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Vaciar &amp;todo</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirmar el envío</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Enviar</translation>
    </message>
    <message>
        <source>Enter a Gridcoin address (e.g. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</source>
        <translation>Introduzca una dirección de Gridcoin (p. ej. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copiar cantidad</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiar cantidad</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copiar comisión</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copiar después de couta</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copiar bytes</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Copiar envío pequeño</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copiar cambio</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; to %2 (%3)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; para %2 (%3)</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirmar enviar monedas</translation>
    </message>
    <message>
        <source>Are you sure you want to send %1?</source>
        <translation>Estás seguro que quieres enviar %1?</translation>
    </message>
    <message>
        <source> and </source>
        <translation>y</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>La dirección de recepción no es válida, compruébela de nuevo.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>La cantidad a pagar debe de ser mayor que 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>La cantidad excede su saldo.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>El total excede su saldo cuando la comisión de transacción de %1 es incluida.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Se ha encontrado una dirección duplicada. Solo se puede enviar a cada dirección una vez por operación de envío.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed.</source>
        <translation>Error: Falla al crear la transacción.</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected. This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Error: La transacción ha sido rechazada. Esto puede ocurrir si algunas de sus monedas en el monedero ya se gastaron, por ejemplo, si se usa una copia del wallet.dat y se gastaron las monedas de la copia pero no se han marcado como gastadas aquí.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
    <message>
        <source>WARNING: Invalid Gridcoin address</source>
        <translation>ADVERTENCIA: Dirección Gridcoin inválida</translation>
    </message>
    <message>
        <source>WARNING: unknown change address</source>
        <translation>ADVERTENCIA: dirección de cambio desconocida</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Ca&amp;ntidad:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Pagar a:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mensaje:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiqueta:</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    <message>
        <source>The address to send the payment to  (e.g. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</source>
        <translation>La dirección a la que se quiere enviar el pago  (e.g. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar dirección desde portapapeles</translation>
    </message>
    <message>
        <source>Send Custom Message to a Gridcoin Recipient</source>
        <translation>Enviar mensaje personalizado a un destinatario de Gridcoin</translation>
    </message>
    <message>
        <source>Choose address from address book</source>
        <translation>Elije dirección de la libreta de direcciones</translation>
    </message>
    <message>
        <source>Remove this recipient</source>
        <translation>Elimina este beneficiario</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Introduzca una etiqueta para esta dirección para añadirla a su lista de direcciones.</translation>
    </message>
    <message>
        <source>Enter a Gridcoin address (e.g. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</source>
        <translation>Introduzca una dirección de Gridcoin (p. ej. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Firmas - Firmar / verificar un mensaje</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Firmar mensaje</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Puede firmar mensajes con sus direcciones para demostrar que las posee. Tenga cuidado de no firmar cualquier cosa vaga, ya que los ataques de phishing pueden tratar de engañarle para suplantar su identidad. Firme solo declaraciones totalmente detalladas con las que usted esté de acuerdo.</translation>
    </message>
    <message>
        <source>The address to sign the message with (e.g. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</source>
        <translation>La dirección para firmar el mensaje con (por ejemplo, Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>Elije una dirección de la libreta de direcciones</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar dirección desde portapapeles</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Introduzca el mensaje que desea firmar aquí</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Copiar la firma actual al portapapeles del sistema</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Gridcoin address</source>
        <translation>Firma el mensaje para demostrar que posees esta dirección Gridcoin.</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Firmar &amp;mensaje</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Vaciar todos los campos de la firma de mensaje</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Vaciar &amp;todo</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verificar mensaje</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Introduzca la dirección para la firma, el mensaje (asegurándose de copiar tal cual los saltos de línea, espacios, tabulaciones, etc.) y la firma a continuación para verificar el mensaje. Tenga cuidado de no asumir más información de lo que dice el propio mensaje firmado para evitar fraudes basados en ataques de tipo man-in-the-middle.</translation>
    </message>
    <message>
        <source>The address the message was signed with (e.g. Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</source>
        <translation>La dirección con la que se firmó el mensaje (por ejemplo, Sjz75uKHzUQJnSdzvpiigEGxseKkDhQToX)</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Gridcoin address</source>
        <translation>Verifique el mensaje para asegurarse de que se firmó con la dirección Gridcoin especificada.</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Vaciar todos los campos de la verificación de mensaje</translation>
    </message>
    <message>
        <source>Enter a Gridcoin address (e.g. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</source>
        <translation>Introduzca una dirección de Gridcoin (p. ej. S67nL4vELWwdDVzjgtEP4MxryarTZ9a8GB)</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Click en "Fírmar mensaje" para generar una firma</translation>
    </message>
    <message>
        <source>Enter Gridcoin signature</source>
        <translation>Introduce la firma Gridcoin</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>La dirección introducida no es válida.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Por favor revise la dirección e inténtelo de nuevo.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>La dirección introducida no remite a una clave.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>El desbloqueo del monedero fue cancelado.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>La clave privada de la dirección introducida no está disponible.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Falló la firma del mensaje.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Mensaje firmado.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>La firma no pudo descodificarse.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Por favor compruebe la firma y pruebe de nuevo.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>La firma no se combinó con el mensaje.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Falló la verificación del mensaje.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Mensaje verificado.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Abierto hasta %1</translation>
    </message>
    <message>
        <source>conflicted</source>
        <translation>en conflicto</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/sin conexión</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/no confirmado</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>confirmaciones %1</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, no ha sido emitido con éxito aún</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Desde</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconocido</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Para</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>dirección propia</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etiqueta</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Credito</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>no aceptada</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Enviado</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Comisión de transacción</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Cantidad neta</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mensaje</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentario</translation>
    </message>
    <message>
        <source>Gridcoin generated coins must mature 110 blocks before they can be spent. When you generated this block, it was broadcast to the network to be added to the block chain. If it fails to get into the chain, its state will change to "not accepted" and it won't be spendable. This may occasionally happen if another node generates a block within a few seconds of yours.</source>
        <translation>Gridcoin generada monedas deben madurar 110 bloques antes de que se pueden gastar. Cuando se genera este bloque, se transmitió a la red para ser añadido a la cadena de bloque. Si no consigue entrar en la cadena, su estado cambia a "no aceptado" y no es gastar. Ocasionalmente esto puede ocurrir si otro nodo genera un bloque en unos segundos del tuyo.
</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <source>true</source>
        <translation>verdadero</translation>
    </message>
    <message>
        <source>false</source>
        <translation>falso</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Detalles de transacción</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Esta ventana muestra información detallada sobre la transacción</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Abierto hasta %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Sin conexion</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Sin confirmar</translation>
    </message>
    <message>
        <source>Confirming (%1 of %2 recommended confirmations)&lt;br&gt;</source>
        <translation>Confirmación (%1 de%2 confirmaciones recomendadas)&lt;br&gt;</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Confirmado (%1 confirmaciones)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>En conflicto</translation>
    </message>
    <message>
        <source>Immature (%1 confirmations, will be available after %2)&lt;br&gt;</source>
        <translation>Inmaduros (%1 confirmaciones, estarán disponibles después de %2)&lt;br&gt;</translation>
    </message>
    <message>
        <source>This block was not received by any other nodes&lt;br&gt; and will probably not be accepted!</source>
        <translation>Este bloque no fue recibido por otros nodos&lt;br&gt;y probablemente no será aceptada!</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generado pero no aceptado</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Recibido con</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Recibidos de</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviado a</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pago proprio</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(nd)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Estado de transacción. Pasa el ratón sobre este campo para ver el número de confirmaciones.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Fecha y hora en que se recibió la transacción.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipo de transacción.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Dirección de destino de la transacción.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Cantidad retirada o añadida al saldo.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Esta semana</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Este mes</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Mes pasado</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Este año</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Rango...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Recibido con</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviado a</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>A usted mismo</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minado</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Otra</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Cantidad mínima</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copiar ubicación</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copiar capa</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiar cantidad</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copiar ID de transacción</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Editar etiqueta</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Mostrar detalles de la transacción</translation>
    </message>
    <message>
        <source>Export Transaction Data</source>
        <translation>Exportar datos de transacción</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Error al exportar</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>No se puede escribir en el archivo %1.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Rango:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>para</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>Enviando...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Ha ocurrido un error al configurar el puerto RPC %u para escuchar mediante IPv6. Recurriendo a IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Ha ocurrido un error al configurar el puerto RPC %u para escucha en IPv4: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Uso:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Muestra comandos
</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Recibir ayuda para un comando
</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Aviso: ¡-paytxfee tiene un valor muy alto! Esta es la comisión que pagará si envía una transacción.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Aviso: ¡Recuperados datos de wallet.dat corrupto! El wallet.dat original se ha guardado como wallet.{timestamp}.bak en %s; si hubiera errores en su saldo o transacciones, deberá restaurar una copia de seguridad.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Aviso: ¡Error al leer wallet.dat! Todas las claves se han leído correctamente, pero podrían faltar o ser incorrectos los datos de transacciones o las entradas de la libreta de direcciones.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed  </source>
        <translation>Error: Error en la creación de la transacción</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected.  This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Error: La transacción ha sido rechazada. Esto puede ocurrir si algunas de sus monedas en el monedero ya se gastaron, por ejemplo, si se usa una copia del wallet.dat y se gastaron las monedas de la copia pero no se han marcado como gastadas aquí.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Ha fallado la escucha en todos los puertos. Use -listen=0 si desea esto.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Para utilizar la opción %s</translation>
    </message>
    <message>
        <source>%s, you must set a rpcpassword in the configuration file:
 %s
It is recommended you use the following random password:
rpcuser=gridcoinrpc
rpcpassword=%s
(you do not need to remember this password)
The username and password MUST NOT be the same.
If the file does not exist, create it with owner-readable-only file permissions.
It is also recommended to set alertnotify so you are notified of problems;
for example: alertnotify=echo %%s | mail -s "Gridcoin Alert" admin@foo.com
</source>
        <translation>%s, debe establecer un rpcpassword en el archivo de configuración:
 %s
Se recomienda utilizar la siguiente contraseña aleatoria:
rpcuser=gridcoinrpc
rpcpassword=%s
(no necesita recordar esta contraseña)
El nombre de usuario y la contraseña NO DEBEN ser los mismos.
Si el archivo no existe, créelo con permisos de archivo legibles por el propietario.
También se recomienda establecer alertnotify para que se le notifique de problemas;
Por ejemplo: alertnotify=echo %%s | mail -s "Alerta de Gridcoin" admin@foo.com</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Tiene que establecer rpcpassword=&lt;contraseña&gt; en el fichero de configuración: ?
%s ?
Si el archivo no existe, créelo con permiso de lectura solamente del propietario.</translation>
    </message>
    <message>
        <source>Gridcoin version</source>
        <translation>versión Gridcoin</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Cantidad inválida para -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -mininput=&lt;amount&gt;: '%s'</source>
        <translation>Cantidad no válida para -mininput=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Initialization sanity check failed. Gridcoin is shutting down.</source>
        <translation>Error al comprobar la sanidad de inicialización. Gridcoin se está cerrando.</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>El monedero %s reside fuera del directorio de datos %s.</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>Verificando la integridad de la base de datos...</translation>
    </message>
    <message>
        <source>Error initializing database environment %s! To recover, BACKUP THAT DIRECTORY, then remove everything from it except for wallet.dat.</source>
        <translation>Error al inicializar el entorno de base de datos %s! Para recuperar, HAGA UNA COPIA DE SEGURIDAD DEL DIRECTORIO, a continuación, elimine todo de ella excepto el archivo wallet.dat.</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat corrupto, ha fallado la recuperación</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Dirección -proxy inválida: '%s'</translation>
    </message>
    <message>
        <source>Invalid -tor address: '%s'</source>
        <translation>Dirección -tor inválida: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>No se puede resolver la dirección de -bind: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>No se puede resolver la dirección de -externalip: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -reservebalance=&lt;amount&gt;</source>
        <translation>Cantidad no válida para -reservebalance=&lt;amount&gt;</translation>
    </message>
    <message>
        <source>Error loading blkindex.dat</source>
        <translation>Error al cargar blkindex.dat</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Error al cargar wallet.dat: el monedero está dañado</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet requires newer version of Gridcoin</source>
        <translation>Error cargando wallet.dat: El monedero requiere una nueva versión de Gridcoin</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart Gridcoin to complete</source>
        <translation>El monedero necesita ser reescrito: reinicie Gridcoin para completar</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Error al cargar wallet.dat</translation>
    </message>
    <message>
        <source>Importing bootstrap blockchain data file.</source>
        <translation>Importando el archivo de datos de arranque de la cadena de bloques.</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Cargando direcciones...</translation>
    </message>
    <message>
        <source>Error: could not start node</source>
        <translation>Error: no se pudo iniciar el nodo</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. Gridcoin is probably already running.</source>
        <translation>No se puede enlazar a %s en este equipo. Gridcoin probablemente ya esté en funcionamiento.</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>No es posible conectar con %s en este sistema (bind ha dado el error %d, %s)</translation>
    </message>
    <message>
        <source>Error: Wallet locked, unable to create transaction  </source>
        <translation>Error: Monedero bloqueado, no es posible crear una transacción</translation>
    </message>
    <message>
        <source>Error: Wallet unlocked for staking only, unable to create transaction.</source>
        <translation>Error: Monedero desbloqueado sólo para hacer "stake", no es posible crear una transacción.</translation>
    </message>
    <message>
        <source>Error: This transaction requires a transaction fee of at least %s because of its amount, complexity, or use of recently received funds  </source>
        <translation>Error: Esta transacción requiere una tarifa de transacción de al menos %s debido a su cantidad, complejidad o uso de los fondos recibidos recientemente</translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Enviando...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Cuantía no válida</translation>
    </message>
    <message>
        <source>Warning: Please check that your computer's date and time are correct! If your clock is wrong Gridcoin will not work properly.</source>
        <translation>Advertencia: Verifique que la fecha y hora del equipo sean correctas! Si su reloj es erróneo Gridcoin no funcionará correctamente.</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>Advertencia: Espacio en disco bajo!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>La red especificada en -onlynet '%s' es desconocida</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Fondos insuficientes</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Cargando el índice de bloques...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Cargando monedero...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>No se puede escribir la dirección predeterminada</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Reexplorando...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Se terminó de cargar</translation>
    </message>
    </context>
</TS>